=================
django-cms-search
=================

This package provides multilingual search indexes for easy Haystack integration with django CMS.

Usage
=====

After installing django-cms-search through your package manager of choice, add ``cms_search`` to your
``INSTALLED_APPS``. That's it.

For setting up Haystack, please refer to their `documentation <http://docs.haystacksearch.org/dev/>`_.

For more docs, see the ``docs`` folder or the
`online documentation <http://django-cms-search.readthedocs.org/en/latest/>`_.